@@ -585,6 +585,7 @@ get_symbol()
 }
 
 VLC_MODULES=$(find_modules vlc/$VLC_BUILD_DIR/modules)
+EXTRA_MODULES="demuxdump2"
 DEFINITION="";
 BUILTINS="const void *vlc_static_modules[] = {\n";
 for file in $VLC_MODULES; do
@@ -617,6 +618,11 @@ EOF
     DEFINITION=$DEFINITION"int vlc_entry__$name (int (*)(void *, void *, int, ...), void *);\n";
     BUILTINS="$BUILTINS vlc_entry__$name,\n";
 done;
+for module in ${EXTRA_MODULES}; do
+    echo $module
+    DEFINITION=$DEFINITION"int vlc_entry__${module} (int (*)(void *, void *, int, ...), void *);\n";
+    BUILTINS="$BUILTINS vlc_entry__${module},\n";
+done
 BUILTINS="$BUILTINS NULL\n};\n"; \
 printf "/* Autogenerated from the list of modules */\n#include <unistd.h>\n$DEFINITION\n$BUILTINS\n" > libvlc/jni/libvlcjni-modules.c
 
