@@ -35,6 +35,7 @@ import android.view.SurfaceHolder;
 import org.videolan.libvlc.LibVLC;
 import org.videolan.libvlc.Media;
 
+import java.io.File;
 import java.io.FileDescriptor;
 import java.io.IOException;
 import java.util.Map;
@@ -278,12 +279,12 @@ public class MediaPlayer
     public static final String MEDIA_MIMETYPE_TEXT_SUBRIP = "application/x-subrip";
 
     public void addTimedTextSource(String path, String mimeType) {
-        mMediaPlayer.setSubtitleFile(path);
+        mMediaPlayer.addSlave(Media.Slave.Type.Subtitle, path);
     }
 
     // FIXME: This is incorrect, since libVLC can only add local subtitles
     public void addTimedTextSource(Context context, Uri uri, String mimeType) {
-        mMediaPlayer.setSubtitleFile(uri.getPath());
+        mMediaPlayer.addSlave(Media.Slave.Type.Subtitle, uri);
     }
 
     public void addTimedTextSource(FileDescriptor fd, String mimeType)
