@@ -353,7 +353,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
     private OnAudioFocusChangeListener createOnAudioFocusChangeListener() {
         return new OnAudioFocusChangeListener() {
             private boolean mLossTransient = false;
-            private int mLossTransientVolume = -1;
+            private boolean mLossTransientCanDuck = false;
             private boolean wasPlaying = false;
 
             @Override
@@ -381,15 +381,15 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
                         // Lower the volume
                         if (mMediaPlayer.isPlaying()) {
                             mMediaPlayer.setVolume(36);
-                            mLossTransientVolume = mMediaPlayer.getVolume();
+                            mLossTransientCanDuck = true;
                         }
                         break;
                     case AudioManager.AUDIOFOCUS_GAIN:
-                        Log.i(TAG, "AUDIOFOCUS_GAIN: " + mLossTransientVolume + ", " + mLossTransient);
+                        Log.i(TAG, "AUDIOFOCUS_GAIN: " + mLossTransientCanDuck + ", " + mLossTransient);
                         // Resume playback
-                        if (mLossTransientVolume != -1) {
-                            mMediaPlayer.setVolume(mLossTransientVolume);
-                            mLossTransientVolume = -1;
+                        if (mLossTransientCanDuck) {
+                            mMediaPlayer.setVolume(100);
+                            mLossTransientCanDuck = false;
                         } else if (mLossTransient) {
                             if (wasPlaying)
                                 mMediaPlayer.play();
@@ -1719,6 +1719,14 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
                 }
             });
         }
+        VLCApplication.runBackground(new Runnable() {
+            @Override
+            public void run() {
+                final ArrayList<Media.Slave> list = MediaDatabase.getInstance().getSlaves(mw.getLocation());
+                for (Media.Slave slave : list)
+                    mMediaPlayer.addSlave(slave.type, Uri.parse(slave.uri));
+            }
+        });
 
         media.setEventListener(mMediaListener);
         mMediaPlayer.setMedia(media);
@@ -2018,7 +2026,12 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
 
     @MainThread
     public boolean addSubtitleTrack(String path) {
-        return mMediaPlayer.setSubtitleFile(path);
+        return mMediaPlayer.addSlave(Media.Slave.Type.Subtitle, path);
+    }
+
+    @MainThread
+    public boolean addSubtitleTrack(Uri uri) {
+        return mMediaPlayer.addSlave(Media.Slave.Type.Subtitle, uri);
     }
 
     @MainThread
