@@ -31,9 +31,9 @@ import android.view.ViewGroup;
 import android.widget.CheckBox;
 
 import org.videolan.libvlc.Media;
-import org.videolan.vlc.media.MediaWrapper;
 import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
+import org.videolan.vlc.media.MediaWrapper;
 
 public class StorageBrowserAdapter extends BaseBrowserAdapter {
 
@@ -60,33 +60,21 @@ public class StorageBrowserAdapter extends BaseBrowserAdapter {
         final Storage storage = (Storage) getItem(position);
         String storagePath = storage.getUri().getPath();
         boolean hasContextMenu = mCustomDirsLocation.contains(storagePath);
-        vh.binding.setHandler(mClickHandler);
-        vh.binding.setPosition(position);
         vh.binding.setStorage(storage);
         vh.binding.setHasContextMenu(hasContextMenu);
         vh.binding.setType(TYPE_STORAGE);
         vh.binding.setChecked(((StorageBrowserFragment) fragment).mScannedDirectory ||
                 (isRoot && (mMediaDirsLocation == null || mMediaDirsLocation.isEmpty())) ||
                 mMediaDirsLocation.contains(storagePath));
-        vh.binding.setChechEnabled(!((StorageBrowserFragment) fragment).mScannedDirectory);
-        vh.checkBox.setOnClickListener(new View.OnClickListener() {
-            @Override
-            public void onClick(View v) {
-                boolean isChecked = ((CheckBox) v).isChecked();
-                String path = ((Storage) getItem(vh.getAdapterPosition())).getUri().getPath();
-                if (isChecked)
-                    addDir(path);
-                else
-                    removeDir(path);
-            }
-        });
+        vh.binding.setCheckEnabled(!((StorageBrowserFragment) fragment).mScannedDirectory);
         if (hasContextMenu)
-            vh.itemView.setOnLongClickListener(this);
+            vh.setContextMenuListener();
     }
 
-    public void addItem(Media media, boolean notify, boolean top){
-        Storage storage = new Storage(media.getUri());
-        addItem(storage, notify, top);
+    public void addItem(Object item, boolean notify, boolean top){
+        if (item instanceof Media)
+            item = new Storage(((Media)item).getUri());
+        super.addItem(item, notify, top);
     }
 
     private void removeDir(final String path) {
@@ -127,7 +115,7 @@ public class StorageBrowserAdapter extends BaseBrowserAdapter {
 //                }
                 //Remove subfolders, it would be redundant
                 for (String customDirPath : mMediaDirsLocation) {
-                    if (customDirPath.startsWith(path+"/"))
+                    if (customDirPath.startsWith(path + "/"))
                         mDbManager.removeDir(customDirPath);
                 }
                 updateMediaDirs();
@@ -145,16 +133,14 @@ public class StorageBrowserAdapter extends BaseBrowserAdapter {
         });
     }
 
-    protected void openMediaFromView(View v) {
-        MediaViewHolder holder = (MediaViewHolder) v.getTag(R.id.layout_item);
+    protected void openMediaFromView(MediaViewHolder holder, View v) {
         MediaWrapper mw = new MediaWrapper(((Storage) getItem(holder.getAdapterPosition())).getUri());
         mw.setType(MediaWrapper.TYPE_DIR);
-        fragment.browse(mw, holder.getAdapterPosition(), holder.checkBox.isChecked());
+        fragment.browse(mw, holder.getAdapterPosition(), holder.binding.browserCheckbox.isChecked());
     }
 
-    protected void checkBoxAction(View v){
+    protected void checkBoxAction(View v, String path){
             boolean isChecked = ((CheckBox) v).isChecked();
-            String path = ((Storage) getItem(((Integer)v.getTag()).intValue())).getUri().getPath();
             if (isChecked)
                 addDir(path);
             else
