@@ -297,7 +297,9 @@ public class PopupManager implements PlaybackService.Callback, GestureDetector.O
         builder.addAction(R.drawable.ic_popup_expand_w, mService.getString(R.string.popup_expand), piExpand);
 
         Notification notification = builder.build();
-        NotificationManagerCompat.from(mService).notify(42, notification);
+        try {
+            NotificationManagerCompat.from(mService).notify(42, notification);
+        } catch (IllegalArgumentException e) {}
     }
 
     private void hideNotification() {
